Class: VietnamQrPay::Bank
- Inherits:
-
Struct
- Object
- Struct
- VietnamQrPay::Bank
- Defined in:
- lib/vietnam_qr_pay/models/bank.rb
Overview
A generated bank catalog entry mirrored from the upstream JavaScript data.
Instance Attribute Summary collapse
-
#bin ⇒ Object
Returns the value of attribute bin.
-
#code ⇒ Object
Returns the value of attribute code.
-
#deprecated ⇒ Object
Returns the value of attribute deprecated.
-
#key ⇒ Object
Returns the value of attribute key.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#lookup_supported ⇒ Object
Returns the value of attribute lookup_supported.
-
#name ⇒ Object
Returns the value of attribute name.
-
#short_name ⇒ Object
Returns the value of attribute short_name.
-
#swift_code ⇒ Object
Returns the value of attribute swift_code.
-
#viet_qr_status ⇒ Object
Returns the value of attribute viet_qr_status.
Instance Method Summary collapse
-
#to_h ⇒ Object
Convenience export for callers that prefer hashes over structs.
Instance Attribute Details
#bin ⇒ Object
Returns the value of attribute bin
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def bin @bin end |
#code ⇒ Object
Returns the value of attribute code
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def code @code end |
#deprecated ⇒ Object
Returns the value of attribute deprecated
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def deprecated @deprecated end |
#key ⇒ Object
Returns the value of attribute key
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def key @key end |
#keywords ⇒ Object
Returns the value of attribute keywords
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def keywords @keywords end |
#lookup_supported ⇒ Object
Returns the value of attribute lookup_supported
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def lookup_supported @lookup_supported end |
#name ⇒ Object
Returns the value of attribute name
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def name @name end |
#short_name ⇒ Object
Returns the value of attribute short_name
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def short_name @short_name end |
#swift_code ⇒ Object
Returns the value of attribute swift_code
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def swift_code @swift_code end |
#viet_qr_status ⇒ Object
Returns the value of attribute viet_qr_status
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 5 def viet_qr_status @viet_qr_status end |
Instance Method Details
#to_h ⇒ Object
Convenience export for callers that prefer hashes over structs.
19 20 21 |
# File 'lib/vietnam_qr_pay/models/bank.rb', line 19 def to_h members.each_with_object({}) { |member, hash| hash[member] = public_send(member) } end |