Class: VietnamQrPay::BankApp
- Inherits:
-
Struct
- Object
- Struct
- VietnamQrPay::BankApp
- Defined in:
- lib/vietnam_qr_pay/models/bank_app.rb
Overview
App-deeplink metadata for a bank mobile app.
Instance Attribute Summary collapse
-
#app_store_id ⇒ Object
Returns the value of attribute app_store_id.
-
#bank ⇒ Object
Returns the value of attribute bank.
-
#package_id ⇒ Object
Returns the value of attribute package_id.
-
#scheme ⇒ Object
Returns the value of attribute scheme.
-
#support_viet_qr ⇒ Object
Returns the value of attribute support_viet_qr.
-
#support_vnpay_qr ⇒ Object
Returns the value of attribute support_vnpay_qr.
Instance Method Summary collapse
-
#to_h ⇒ Object
Convenience export for callers that prefer hashes over structs.
Instance Attribute Details
#app_store_id ⇒ Object
Returns the value of attribute app_store_id
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank_app.rb', line 5 def app_store_id @app_store_id end |
#bank ⇒ Object
Returns the value of attribute bank
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank_app.rb', line 5 def bank @bank end |
#package_id ⇒ Object
Returns the value of attribute package_id
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank_app.rb', line 5 def package_id @package_id end |
#scheme ⇒ Object
Returns the value of attribute scheme
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank_app.rb', line 5 def scheme @scheme end |
#support_viet_qr ⇒ Object
Returns the value of attribute support_viet_qr
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank_app.rb', line 5 def support_viet_qr @support_viet_qr end |
#support_vnpay_qr ⇒ Object
Returns the value of attribute support_vnpay_qr
5 6 7 |
# File 'lib/vietnam_qr_pay/models/bank_app.rb', line 5 def support_vnpay_qr @support_vnpay_qr end |
Instance Method Details
#to_h ⇒ Object
Convenience export for callers that prefer hashes over structs.
15 16 17 |
# File 'lib/vietnam_qr_pay/models/bank_app.rb', line 15 def to_h members.each_with_object({}) { |member, hash| hash[member] = public_send(member) } end |